@@ -324,6 +324,8 @@ class EventName(Enum):
     DEVICE_CREATED = "DeviceCreatedEvent"
     DEVICE_DELETION_FAILED = "DeviceDeletionFailedEvent"
     DEVICE_DISABLED = "DeviceDisabledEvent"
+    DEVICE_PROTOCOL_AVAILABLE = "DeviceProtocolAvailableEvent"
+    DEVICE_PROTOCOL_UNAVAILABLE = "DeviceProtocolUnavailableEvent"
     DEVICE_REMOVED = "DeviceRemovedEvent"
     DEVICE_STATE_CHANGED = "DeviceStateChangedEvent"
     DEVICE_UNAVAILABLE = "DeviceUnavailableEvent"
@@ -336,16 +338,18 @@ class EventName(Enum):
     ELIOT_DISCOVER_GATEWAY_FAILED = "EliotDiscoverGatewayFailedEvent"
     ELIOT_REFRESH_CURRENT_TOKEN_COMPLETED = "EliotRefreshCurrentTokenCompletedEvent"
     ELIOT_REFRESH_CURRENT_TOKEN_FAILED = "EliotRefreshCurrentTokenFailedEvent"
+    END_USER_LOGIN = "EndUserLoginEvent"
     ENOCEAN_BAD_DEVICE_STIMULATION = "EnOceanBadDeviceStimulationEvent"
     ENOCEAN_KNOWN_DEVICE_FOUND = "EnOceanKnownDeviceFoundEvent"
     ENOCEAN_LEARN_STARTED = "EnOceanLearnStartedEvent"
     ENOCEAN_LEARN_STOPPED = "EnOceanLearnStoppedEvent"
-    END_USER_LOGIN = "EndUserLoginEvent"
     EXECUTION_REGISTERED = "ExecutionRegisteredEvent"
     EXECUTION_STATE_CHANGED = "ExecutionStateChangedEvent"
     GATEWAY_ALIVE = "GatewayAliveEvent"
+    GATEWAY_BOOT = "GatewayBootEvent"
     GATEWAY_DOWN = "GatewayDownEvent"
     GATEWAY_FUNCTION_CHANGED = "GatewayFunctionChangedEvent"
+    GATEWAY_MODE_CHANGED = "GatewayModeChangedEvent"
     GATEWAY_SYNCHRONIZATION_ENDED = "GatewaySynchronizationEndedEvent"
     GATEWAY_SYNCHRONIZATION_STARTED = "GatewaySynchronizationStartedEvent"
     INVALID_ADDRESS = "InvalidAddressEvent"
@@ -360,12 +364,12 @@ class EventName(Enum):
     PLACE_DELETED = "PlaceDeletedEvent"
     PLACE_UPDATED = "PlaceUpdatedEvent"
     PURGE_PARTIAL_RAW_DEVICES = "PurgePartialRawDevicesEvent"
+    REFRESH_ALL_DEVICES_STATES_COMPLETED = "RefreshAllDevicesStatesCompletedEvent"
     SONOS_GET_TOPOLOGY_SUCCESS = "SonosGetTopologySuccessEvent"
     TOKEN_CREATED = "TokenCreatedEvent"
     TOKEN_CREATION_FAILED = "TokenCreationFailedEvent"
     TOKEN_DELETION_FAILED = "TokenDeletionFailedEvent"
     TOKEN_REMOVED = "TokenRemovedEvent"
-    REFRESH_ALL_DEVICES_STATES_COMPLETED = "RefreshAllDevicesStatesCompletedEvent"
     VALID_ADDRESS = "ValidAddressEvent"
 
 
@@ -376,3 +380,9 @@ class UpdateBoxStatus(Enum):
     READY_TO_UPDATE_LOCALLY = "READY_TO_UPDATE_LOCALLY"
     UP_TO_DATE = "UP_TO_DATE"
     UNKNOWN = "UNKNOWN"
+
+
+class CommandMode(Enum):
+    high_priority = "highPriority"
+    geolocated = "geolocated"
+    internal = "internal"
