@@ -1,4 +1,12 @@
-class TooManyRequestsException(Exception):
+class BadCredentialsException(Exception):
+    pass
+
+
+class InvalidCommandException(Exception):
+    pass
+
+
+class NotAuthenticatedException(Exception):
     pass
 
 
@@ -6,9 +14,9 @@ class TooManyExecutionsException(Exception):
     pass
 
 
-class BadCredentialsException(Exception):
+class TooManyRequestsException(Exception):
     pass
 
 
-class NotAuthenticatedException(Exception):
+class MaintenanceException(Exception):
     pass
